Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/pcm51xx_simpletest.py
    :caption: examples/pcm51xx_simpletest.py
    :linenos:

Full test
----------

Test all of the functionality for the I2S DAC

.. literalinclude:: ../examples/pcm51xx_fulltest.py
    :caption: examples/pcm51xx_fulltest.py
    :linenos:

Sine tone playback
-------------------

Playback a sine tone

.. literalinclude:: ../examples/pcm51xx_sinetone.py
    :caption: examples/pcm51xx_sinetone.py
    :linenos:
